@@ -1,8 +1,9 @@
 from typing import TYPE_CHECKING
 
 import dask.array as da
+import numpy as np
 from magicgui import magic_factory
-from scipy.fft import fftn, fftshift
+from scipy.fft import fftn, fftshift, ifftshift
 
 if TYPE_CHECKING:
     import napari
@@ -14,12 +15,20 @@ if TYPE_CHECKING:
 )
 def power_spectrum(
     image: "napari.layers.Image",
+    is_2D_data: bool = False,
 ) -> "napari.types.LayerDataTuple":
-    axes = (1, 2) if image.metadata["stack"] else None
+    """
+    Power spectrum (log scale) of the image.
+
+    First centers in real space on the origin to remove shift effects.
+    """
+    axes = (-2, -1) if is_2D_data else None
     raw = da.compute(image.data)[0]
-    power_spectrum = abs(fftshift(fftn(raw, axes=axes)))
+    power_spectrum = np.abs(
+        fftshift(fftn(ifftshift(raw, axes=axes), axes=axes), axes=axes)
+    )
     return (
-        power_spectrum,
+        np.log(power_spectrum + 1),
         {"name": f"{image.name} - power spectrum", "scale": image.scale},
         "image",
     )
