@@ -12,9 +12,10 @@ def star_file(tmp_path_factory):
             "rlnCoordinateX": [1, 1],
             "rlnCoordinateY": [2, 2],
             "rlnCoordinateZ": [3, 3],
-            "rlnOriginX": [0.1, 0.1],
-            "rlnOriginY": [0.2, 0.2],
-            "rlnOriginZ": [0.3, 0.3],
+            "rlnOriginXAngst": [0.1, 0.1],
+            "rlnOriginYAngst": [0.2, 0.2],
+            "rlnOriginZAngst": [0.3, 0.3],
+            "rlnImagePixelSize": [1, 1],
             "rlnAngleRot": [0, 0],
             "rlnAngleTilt": [0, 90],
             "rlnAnglePsi": [90, 0],
