@@ -8,9 +8,9 @@ def test_reader(star_file):
     layer_data_list = reader(star_file)
     assert len(layer_data_list) == 4
 
-    pts = layer_data_list[1]
+    pts = layer_data_list[0]
     assert pts[2] == "points"
-    vec = layer_data_list[0]
+    vec = layer_data_list[1]
     assert vec[2] == "vectors"
 
 
@@ -24,7 +24,13 @@ def test_construct_empty_layers():
 
     assert len(layer_data_list) == 2
 
-    pts = layer_data_list[1]
+    pts = layer_data_list[0]
     assert pts[2] == "points"
-    vec = layer_data_list[0]
+    vec = layer_data_list[1]
     assert vec[2] == "vectors"
+
+
+def test_napari_read(star_file, mrc_file, make_napari_viewer):
+    v = make_napari_viewer()
+    v.open(star_file, plugin='blik')
+    v.open(mrc_file, plugin='blik')
